%%%%%%% BARONAS ET AL. (2021) FRONTIERS IN EARTH SCIENCE
%%% "Ge/Si and Ge isotope fractionation during glacial and non-glacial weathering: 
%%% field and experimental data from West Greenland"

%%% Monte Carlo calculation of uncertainties in the Batch model of experimental data
%%% Written by J. Jotautas Baronas
%%% Last tested on MATLAB 2019b. The "random" function requires the Statistics and Machine Learning Toolbox.

%% 
clear
load('GL_alldata.mat') %load data from the separate (attached) file, must be in the same directory
sample_data = data(~isnan(data.d74Ge),:); %extract data w/ d74 values

%colors for plotting
plot_col(2,:) = [1.0000    0.8000    0.6000];
plot_col(3,:) = [1.0000    0.6000    0.6000];
plot_col(14,:) = [0.5    1.0000    0.5];

%measured rock data from JO-14 SPM
d74Ge_rock = 0.48; 
d74Ge_rock_sd = 0.11; % 1SD

%calculate Ge/Si of the dissolving phase as mean1SD of all field-measured values
GeSi_rock_mean =nanmean(data.GeSi(data.Sample == 'Field'));
GeSi_rock_std =std(data.GeSi(data.Sample == 'Field'),'omitnan');

%create a normal probability distribution function for this value
GeSi_rock_pdf = makedist('Normal','mu',GeSi_rock_mean,'sigma',GeSi_rock_std);

n = 10000; %number of Monte Carlo runs

%create vectors of random values of these parameters, of length n
GeSi_rock_r = random(GeSi_rock_pdf, [n,1]);
d74Ge_rock_r = random('Normal', d74Ge_rock, d74Ge_rock_sd, [n,1]);

%create a table to store the results
mod_res = table;

for i = 1:3 %for each of the three samples with d74Ge data
    %create vectors of random values from within analytical uncertainty, of length n
    mod_res.Ge_diss_r(:,i) = random('Normal', sample_data.Ge(i), sample_data.Ge(i).*.05, [n,1]); % 5% uncertainty
    mod_res.Si_diss_r(:,i) = random('Normal', sample_data.Si(i), sample_data.Si(i).*.05, [n,1]); % 5% uncertainty
    mod_res.d74Ge_r(:,i) = random('Normal', sample_data.d74Ge(i), sample_data.d74Ge2SD(i)/2, [n,1]); % absolute uncertainty as in Table 1
    
    mod_res.Ge_bruto_r(:,i) = mod_res.Si_diss_r(:,i) .* GeSi_rock_r; %calc total amount of Ge released
    mod_res.fdissGe_r(:,i) = mod_res.Ge_diss_r(:,i) ./ mod_res.Ge_bruto_r(:,i); %calc the fraction of Ge remaining in solution after secondary uptake
    
end

%add the vector of the random d74Ge values of the dissolving phase into the table
mod_res.d74Ge_r(:,4) = d74Ge_rock_r;

%assign all Ge in solution (fdiss = 1) at the beginning of the experiment (unsampled)
mod_res.fdissGe_r(:,4) = 1;

%remove impossible values with fdiss > 1
mod_sel =  mod_res(mod_res.fdissGe_r(:,3)<=1,:); 

%record the number of retained values
n2 = height(mod_sel);

%fit data to each MC run, get D74Ge_sec-diss from the slope of the linear fit
for j = 1:n2

    fm{j}= fit(mod_sel.fdissGe_r(j,1:4)',mod_sel.d74Ge_r(j,1:4)','poly1'); %perform fit
    D74_r(j,1) = fm{j}.p1; %get slope of fit
end

%calculate mean and std. dev. of the D74Ge_sec-diss fractionation factor. These are the values reported in the paper.
D74_mean = mean(D74_r)
D74_sd = std(D74_r)

%extract mean and SD of fdissGe for plotting purposes
fdiss_mean = mean(mod_sel.fdissGe_r);
fdiss_sd = std(mod_sel.fdissGe_r);


%% plot results
figure;
hold on

pn = 100; %number of MC results to plot as an example

%plot fits 
for j = 1:pn
    xlim([0.2 1]);
    h_fits(j) = plot(fm{j},'-');
    h_fits(j).Color = [0.7412    0.9137    1.0000];
    h_fits(j).LineWidth = 1;
    legend off
end


for i=1:height(sample_data)
    h_mc_diss(i) = errorbar(fdiss_mean(i)',sample_data.d74Ge(i),sample_data.d74Ge2SD(i),sample_data.d74Ge2SD(i),2*fdiss_sd(i)',2*fdiss_sd(i)','ok','MarkerSize',10,'LineWidth',1,'MarkerFaceColor',plot_col(sample_data.Exp(i),:),'CapSize',0);
end

h_mc_rock = errorbar(fdiss_mean(4),d74Ge_rock,d74Ge_rock_sd*2,'p','MarkerFaceColor','k','MarkerEdgeColor',[0.5 0.5 0.5],'MarkerSize',16,'LineWidth',1,'Color',[0.5 0.5 0.5],'CapSize',0);

xlim([0.195 1.01]);

fig_format

xlabel('f_{diss}Ge')
ylabel('\delta^{74}Ge ()')


text(0.05,0.1,"\Delta^{74}Ge_{sec-diss} = " + num2str(round(D74_mean,2)) + "  " + num2str(round(D74_sd*2,2) + ""),'Units','normalized','FontSize',16) 

l = legend([h_mc_diss,h_mc_rock,h_fits(1)],'JO-2 Final','JO-3A Final','JO-14 Field','JO-14 SPM','Monte Carlo fits to Eq. 2');


